from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.Message import *
from OCC.Core.OSD import *
from OCC.Core.TColStd import *

#the following typedef cannot be wrapped as is
MoniTool_IndexedDataMapOfShapeTransient = NewType('MoniTool_IndexedDataMapOfShapeTransient', Any)

class MoniTool_SequenceOfElement:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class MoniTool_ValueType(IntEnum):
	MoniTool_ValueMisc: int = ...
	MoniTool_ValueInteger: int = ...
	MoniTool_ValueReal: int = ...
	MoniTool_ValueIdent: int = ...
	MoniTool_ValueVoid: int = ...
	MoniTool_ValueText: int = ...
	MoniTool_ValueEnum: int = ...
	MoniTool_ValueLogical: int = ...
	MoniTool_ValueSub: int = ...
	MoniTool_ValueHexa: int = ...
	MoniTool_ValueBinary: int = ...
MoniTool_ValueMisc = MoniTool_ValueType.MoniTool_ValueMisc
MoniTool_ValueInteger = MoniTool_ValueType.MoniTool_ValueInteger
MoniTool_ValueReal = MoniTool_ValueType.MoniTool_ValueReal
MoniTool_ValueIdent = MoniTool_ValueType.MoniTool_ValueIdent
MoniTool_ValueVoid = MoniTool_ValueType.MoniTool_ValueVoid
MoniTool_ValueText = MoniTool_ValueType.MoniTool_ValueText
MoniTool_ValueEnum = MoniTool_ValueType.MoniTool_ValueEnum
MoniTool_ValueLogical = MoniTool_ValueType.MoniTool_ValueLogical
MoniTool_ValueSub = MoniTool_ValueType.MoniTool_ValueSub
MoniTool_ValueHexa = MoniTool_ValueType.MoniTool_ValueHexa
MoniTool_ValueBinary = MoniTool_ValueType.MoniTool_ValueBinary

class MoniTool_AttrList:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, other: MoniTool_AttrList) -> None: ...
	def AttrList(self) -> False: ...
	def Attribute(self, name: str) -> Standard_Transient: ...
	def AttributeType(self, name: str) -> MoniTool_ValueType: ...
	def GetAttribute(self, name: str, type: Standard_Type, val: Standard_Transient) -> bool: ...
	def GetAttributes(self, other: MoniTool_AttrList, fromname: Optional[str] = "", copied: Optional[bool] = True) -> None: ...
	def GetIntegerAttribute(self, name: str) -> Tuple[bool, int]: ...
	def GetRealAttribute(self, name: str) -> Tuple[bool, float]: ...
	def GetStringAttribute(self, name: str, val: str) -> bool: ...
	def IntegerAttribute(self, name: str) -> int: ...
	def RealAttribute(self, name: str) -> float: ...
	def RemoveAttribute(self, name: str) -> bool: ...
	def SameAttributes(self, other: MoniTool_AttrList) -> None: ...
	def SetAttribute(self, name: str, val: Standard_Transient) -> None: ...
	def SetIntegerAttribute(self, name: str, val: int) -> None: ...
	def SetRealAttribute(self, name: str, val: float) -> None: ...
	def SetStringAttribute(self, name: str, val: str) -> None: ...
	def StringAttribute(self, name: str) -> str: ...

class MoniTool_CaseData(Standard_Transient):
	def __init__(self, caseid: Optional[str] = "", name: Optional[str] = "") -> None: ...
	def AddAny(self, val: Standard_Transient, name: Optional[str] = "") -> None: ...
	def AddCPU(self, lastCPU: float, curCPU: Optional[float] = 0, name: Optional[str] = "") -> None: ...
	def AddData(self, val: Standard_Transient, kind: int, name: Optional[str] = "") -> None: ...
	def AddEntity(self, ent: Standard_Transient, name: Optional[str] = "") -> None: ...
	def AddGeom(self, geom: Standard_Transient, name: Optional[str] = "") -> None: ...
	def AddInteger(self, val: int, name: Optional[str] = "") -> None: ...
	def AddRaised(self, theException: Standard_Failure, name: Optional[str] = "") -> None: ...
	def AddReal(self, val: float, name: Optional[str] = "") -> None: ...
	def AddReals(self, v1: float, v2: float, name: Optional[str] = "") -> None: ...
	def AddShape(self, sh: TopoDS_Shape, name: Optional[str] = "") -> None: ...
	def AddText(self, text: str, name: Optional[str] = "") -> None: ...
	def AddXY(self, aXY: gp_XY, name: Optional[str] = "") -> None: ...
	def AddXYZ(self, aXYZ: gp_XYZ, name: Optional[str] = "") -> None: ...
	def CaseId(self) -> str: ...
	def Data(self, nd: int) -> Standard_Transient: ...
	@staticmethod
	def DefCheck(acode: str) -> int: ...
	@staticmethod
	def DefMsg(casecode: str) -> str: ...
	def GetCPU(self) -> float: ...
	def GetData(self, nd: int, type: Standard_Type, val: Standard_Transient) -> bool: ...
	def Integer(self, nd: int) -> Tuple[bool, int]: ...
	def IsCheck(self) -> bool: ...
	def IsFail(self) -> bool: ...
	def IsWarning(self) -> bool: ...
	def Kind(self, nd: int) -> int: ...
	def LargeCPU(self, maxCPU: float, lastCPU: float, curCPU: Optional[float] = 0) -> bool: ...
	def Msg(self) -> Message_Msg: ...
	@overload
	def Name(self) -> str: ...
	@overload
	def Name(self, nd: int) -> TCollection_AsciiString: ...
	def NameNum(self, name: str) -> int: ...
	def NbData(self) -> int: ...
	def Real(self, nd: int) -> Tuple[bool, float]: ...
	def Reals(self, nd: int) -> Tuple[bool, float, float]: ...
	def RemoveData(self, num: int) -> None: ...
	def ResetCheck(self) -> None: ...
	def SetCaseId(self, caseid: str) -> None: ...
	def SetChange(self) -> None: ...
	@staticmethod
	def SetDefFail(acode: str) -> None: ...
	@staticmethod
	def SetDefMsg(casecode: str, mesdef: str) -> None: ...
	@staticmethod
	def SetDefWarning(acode: str) -> None: ...
	def SetFail(self) -> None: ...
	def SetName(self, name: str) -> None: ...
	def SetReplace(self, num: int) -> None: ...
	def SetWarning(self) -> None: ...
	def Shape(self, nd: int) -> TopoDS_Shape: ...
	def Text(self, nd: int, text: str) -> bool: ...
	def XY(self, nd: int, val: gp_XY) -> bool: ...
	def XYZ(self, nd: int, val: gp_XYZ) -> bool: ...

class MoniTool_DataInfo:
	@staticmethod
	def Type(ent: Standard_Transient) -> Standard_Type: ...
	@staticmethod
	def TypeName(ent: Standard_Transient) -> str: ...

class MoniTool_ElemHasher:
	@staticmethod
	def HashCode(theElement: MoniTool_Element, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(K1: MoniTool_Element, K2: MoniTool_Element) -> bool: ...

class MoniTool_Element(Standard_Transient):
	def ChangeAttr(self) -> MoniTool_AttrList: ...
	def Equates(self, other: MoniTool_Element) -> bool: ...
	def GetHashCode(self) -> int: ...
	def ListAttr(self) -> MoniTool_AttrList: ...
	def ValueType(self) -> Standard_Type: ...
	def ValueTypeName(self) -> str: ...

class MoniTool_IntVal(Standard_Transient):
	def __init__(self, val: Optional[int] = 0) -> None: ...
	def GetCValue(self) -> int: ...
	def SetCValue(self, value: int) -> None: ...
	def Value(self) -> int: ...

class MoniTool_MTHasher:
	@staticmethod
	def HashCode(theString: str, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(Str1: str, Str2: str) -> bool: ...

class MoniTool_RealVal(Standard_Transient):
	def __init__(self, val: Optional[float] = 0.0) -> None: ...
	def GetCValue(self) -> float: ...
	def SetCValue(self, value: float) -> None: ...
	def Value(self) -> float: ...

class MoniTool_SignText(Standard_Transient):
	def Name(self) -> str: ...
	def Text(self, ent: Standard_Transient, context: Standard_Transient) -> TCollection_AsciiString: ...
	def TextAlone(self, ent: Standard_Transient) -> TCollection_AsciiString: ...

class MoniTool_Stat:
	@overload
	def __init__(self, title: Optional[str] = "") -> None: ...
	@overload
	def __init__(self, other: MoniTool_Stat) -> None: ...
	def Add(self, nb: Optional[int] = 1) -> None: ...
	def AddEnd(self) -> None: ...
	def AddSub(self, nb: Optional[int] = 1) -> None: ...
	def Close(self, id: int) -> None: ...
	@staticmethod
	def Current() -> MoniTool_Stat: ...
	def Level(self) -> int: ...
	def Open(self, nb: Optional[int] = 100) -> int: ...
	def OpenMore(self, id: int, nb: int) -> None: ...
	def Percent(self, fromlev: Optional[int] = 0) -> float: ...

class MoniTool_Timer(Standard_Transient):
	def __init__(self) -> None: ...
	def Amend(self) -> float: ...
	def CPU(self) -> float: ...
	@staticmethod
	def ClearTimers() -> None: ...
	@staticmethod
	def ComputeAmendments() -> None: ...
	def Count(self) -> int: ...
	@staticmethod
	def Dictionary() -> MoniTool_DataMapOfTimer: ...
	@staticmethod
	def GetAmendments() -> Tuple[float, float, float, float]: ...
	def IsRunning(self) -> int: ...
	def Reset(self) -> None: ...
	@overload
	def Start(self) -> None: ...
	@overload
	@staticmethod
	def Start(name: str) -> None: ...
	@overload
	def Stop(self) -> None: ...
	@overload
	@staticmethod
	def Stop(name: str) -> None: ...
	@overload
	def Timer(self) -> OSD_Timer: ...
	@overload
	def Timer(self) -> OSD_Timer: ...
	@overload
	@staticmethod
	def Timer(name: str) -> MoniTool_Timer: ...

class MoniTool_TimerSentry:
	@overload
	def __init__(self, cname: str) -> None: ...
	@overload
	def __init__(self, timer: MoniTool_Timer) -> None: ...
	def Stop(self) -> None: ...
	def Timer(self) -> MoniTool_Timer: ...

class MoniTool_TypedValue(Standard_Transient):
	@overload
	def __init__(self, name: str, type: Optional[MoniTool_ValueType] = MoniTool_ValueText, init: Optional[str] = "") -> None: ...
	@overload
	def __init__(self, other: MoniTool_TypedValue) -> None: ...
	def AddDef(self, initext: str) -> bool: ...
	def AddEnum(self, v1: Optional[str] = "", v2: Optional[str] = "", v3: Optional[str] = "", v4: Optional[str] = "", v5: Optional[str] = "", v6: Optional[str] = "", v7: Optional[str] = "", v8: Optional[str] = "", v9: Optional[str] = "", v10: Optional[str] = "") -> None: ...
	def AddEnumValue(self, val: str, num: int) -> None: ...
	@staticmethod
	def AddLib(tv: MoniTool_TypedValue, def_: Optional[str] = "") -> bool: ...
	def CStringValue(self) -> str: ...
	def ClearValue(self) -> None: ...
	def Definition(self) -> TCollection_AsciiString: ...
	def EnumCase(self, val: str) -> int: ...
	def EnumDef(self) -> Tuple[bool, int, int, bool]: ...
	def EnumVal(self, num: int) -> str: ...
	@staticmethod
	def FromLib(def_: str) -> MoniTool_TypedValue: ...
	def GetObjectValue(self, val: Standard_Transient) -> None: ...
	def HStringValue(self) -> TCollection_HAsciiString: ...
	def HasInterpret(self) -> bool: ...
	def IntegerLimit(self, max: bool) -> Tuple[bool, int]: ...
	def IntegerValue(self) -> int: ...
	def Interpret(self, hval: TCollection_HAsciiString, native: bool) -> TCollection_HAsciiString: ...
	def IsSetValue(self) -> bool: ...
	def Label(self) -> str: ...
	@staticmethod
	def Lib(def_: str) -> MoniTool_TypedValue: ...
	@staticmethod
	def LibList() -> TColStd_HSequenceOfAsciiString: ...
	def MaxLength(self) -> int: ...
	def Name(self) -> str: ...
	def ObjectType(self) -> Standard_Type: ...
	def ObjectTypeName(self) -> str: ...
	def ObjectValue(self) -> Standard_Transient: ...
	def RealLimit(self, max: bool) -> Tuple[bool, float]: ...
	def RealValue(self) -> float: ...
	def Satisfies(self, hval: TCollection_HAsciiString) -> bool: ...
	def SatisfiesName(self) -> str: ...
	def SetCStringValue(self, val: str) -> bool: ...
	def SetDefinition(self, deftext: str) -> None: ...
	def SetHStringValue(self, hval: TCollection_HAsciiString) -> bool: ...
	def SetIntegerLimit(self, max: bool, val: int) -> None: ...
	def SetIntegerValue(self, ival: int) -> bool: ...
	def SetInterpret(self, func: MoniTool_ValueInterpret) -> None: ...
	def SetLabel(self, label: str) -> None: ...
	def SetMaxLength(self, max: int) -> None: ...
	def SetObjectType(self, typ: Standard_Type) -> None: ...
	def SetObjectValue(self, obj: Standard_Transient) -> bool: ...
	def SetRealLimit(self, max: bool, val: float) -> None: ...
	def SetRealValue(self, rval: float) -> bool: ...
	def SetSatisfies(self, func: MoniTool_ValueSatisfies, name: str) -> None: ...
	def SetUnitDef(self, def_: str) -> None: ...
	def StartEnum(self, start: Optional[int] = 0, match: Optional[bool] = True) -> None: ...
	@staticmethod
	def StaticValue(name: str) -> MoniTool_TypedValue: ...
	def UnitDef(self) -> str: ...
	def ValueType(self) -> MoniTool_ValueType: ...

class MoniTool_SignShape(MoniTool_SignText):
	def __init__(self) -> None: ...
	def Name(self) -> str: ...
	def Text(self, ent: Standard_Transient, context: Standard_Transient) -> TCollection_AsciiString: ...

class MoniTool_TransientElem(MoniTool_Element):
	def __init__(self, akey: Standard_Transient) -> None: ...
	def Equates(self, other: MoniTool_Element) -> bool: ...
	def Value(self) -> Standard_Transient: ...
	def ValueType(self) -> Standard_Type: ...
	def ValueTypeName(self) -> str: ...

# harray1 classes
# harray2 classes
# hsequence classes

class MoniTool_HSequenceOfElement(MoniTool_SequenceOfElement, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: MoniTool_SequenceOfElement) -> None: ...
    def Sequence(self) -> MoniTool_SequenceOfElement: ...
    def Append(self, theSequence: MoniTool_SequenceOfElement) -> None: ...


MoniTool_CaseData_DefCheck = MoniTool_CaseData.DefCheck
MoniTool_CaseData_DefMsg = MoniTool_CaseData.DefMsg
MoniTool_CaseData_SetDefFail = MoniTool_CaseData.SetDefFail
MoniTool_CaseData_SetDefMsg = MoniTool_CaseData.SetDefMsg
MoniTool_CaseData_SetDefWarning = MoniTool_CaseData.SetDefWarning
MoniTool_DataInfo_Type = MoniTool_DataInfo.Type
MoniTool_DataInfo_TypeName = MoniTool_DataInfo.TypeName
MoniTool_ElemHasher_HashCode = MoniTool_ElemHasher.HashCode
MoniTool_ElemHasher_IsEqual = MoniTool_ElemHasher.IsEqual
MoniTool_MTHasher_HashCode = MoniTool_MTHasher.HashCode
MoniTool_MTHasher_IsEqual = MoniTool_MTHasher.IsEqual
MoniTool_Stat_Current = MoniTool_Stat.Current
MoniTool_Timer_ClearTimers = MoniTool_Timer.ClearTimers
MoniTool_Timer_ComputeAmendments = MoniTool_Timer.ComputeAmendments
MoniTool_Timer_Dictionary = MoniTool_Timer.Dictionary
MoniTool_Timer_GetAmendments = MoniTool_Timer.GetAmendments
MoniTool_Timer_Start = MoniTool_Timer.Start
MoniTool_Timer_Stop = MoniTool_Timer.Stop
MoniTool_Timer_Timer = MoniTool_Timer.Timer
MoniTool_TypedValue_AddLib = MoniTool_TypedValue.AddLib
MoniTool_TypedValue_FromLib = MoniTool_TypedValue.FromLib
MoniTool_TypedValue_Lib = MoniTool_TypedValue.Lib
MoniTool_TypedValue_LibList = MoniTool_TypedValue.LibList
MoniTool_TypedValue_StaticValue = MoniTool_TypedValue.StaticValue



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.TopTools import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.ChFi3d import *


class FilletSurf_StatusDone(IntEnum):
	FilletSurf_IsOk: int = ...
	FilletSurf_IsNotOk: int = ...
	FilletSurf_IsPartial: int = ...
FilletSurf_IsOk = FilletSurf_StatusDone.FilletSurf_IsOk
FilletSurf_IsNotOk = FilletSurf_StatusDone.FilletSurf_IsNotOk
FilletSurf_IsPartial = FilletSurf_StatusDone.FilletSurf_IsPartial

class FilletSurf_StatusType(IntEnum):
	FilletSurf_TwoExtremityOnEdge: int = ...
	FilletSurf_OneExtremityOnEdge: int = ...
	FilletSurf_NoExtremityOnEdge: int = ...
FilletSurf_TwoExtremityOnEdge = FilletSurf_StatusType.FilletSurf_TwoExtremityOnEdge
FilletSurf_OneExtremityOnEdge = FilletSurf_StatusType.FilletSurf_OneExtremityOnEdge
FilletSurf_NoExtremityOnEdge = FilletSurf_StatusType.FilletSurf_NoExtremityOnEdge

class FilletSurf_ErrorTypeStatus(IntEnum):
	FilletSurf_EmptyList: int = ...
	FilletSurf_EdgeNotG1: int = ...
	FilletSurf_FacesNotG1: int = ...
	FilletSurf_EdgeNotOnShape: int = ...
	FilletSurf_NotSharpEdge: int = ...
	FilletSurf_PbFilletCompute: int = ...
FilletSurf_EmptyList = FilletSurf_ErrorTypeStatus.FilletSurf_EmptyList
FilletSurf_EdgeNotG1 = FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotG1
FilletSurf_FacesNotG1 = FilletSurf_ErrorTypeStatus.FilletSurf_FacesNotG1
FilletSurf_EdgeNotOnShape = FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotOnShape
FilletSurf_NotSharpEdge = FilletSurf_ErrorTypeStatus.FilletSurf_NotSharpEdge
FilletSurf_PbFilletCompute = FilletSurf_ErrorTypeStatus.FilletSurf_PbFilletCompute

class FilletSurf_Builder:
	def __init__(self, S: TopoDS_Shape, E: TopTools_ListOfShape, R: float, Ta: Optional[float] = 1.0e-2, Tapp3d: Optional[float] = 1.0e-4, Tapp2d: Optional[float] = 1.0e-5) -> None: ...
	def CurveOnFace1(self, Index: int) -> Geom_Curve: ...
	def CurveOnFace2(self, Index: int) -> Geom_Curve: ...
	def EndSectionStatus(self) -> FilletSurf_StatusType: ...
	def FirstParameter(self) -> float: ...
	def IsDone(self) -> FilletSurf_StatusDone: ...
	def LastParameter(self) -> float: ...
	def NbSection(self, IndexSurf: int) -> int: ...
	def NbSurface(self) -> int: ...
	def PCurve1OnFillet(self, Index: int) -> Geom2d_Curve: ...
	def PCurve2OnFillet(self, Index: int) -> Geom2d_Curve: ...
	def PCurveOnFace1(self, Index: int) -> Geom2d_Curve: ...
	def PCurveOnFace2(self, Index: int) -> Geom2d_Curve: ...
	def Perform(self) -> None: ...
	def Section(self, IndexSurf: int, IndexSec: int, Circ: Geom_TrimmedCurve) -> None: ...
	def Simulate(self) -> None: ...
	def StartSectionStatus(self) -> FilletSurf_StatusType: ...
	def StatusError(self) -> FilletSurf_ErrorTypeStatus: ...
	def SupportFace1(self, Index: int) -> TopoDS_Face: ...
	def SupportFace2(self, Index: int) -> TopoDS_Face: ...
	def SurfaceFillet(self, Index: int) -> Geom_Surface: ...
	def TolApp3d(self, Index: int) -> float: ...

class FilletSurf_InternalBuilder(ChFi3d_FilBuilder):
	def __init__(self, S: TopoDS_Shape, FShape: Optional[ChFi3d_FilletShape] = ChFi3d_Polynomial, Ta: Optional[float] = 1.0e-2, Tapp3d: Optional[float] = 1.0e-4, Tapp2d: Optional[float] = 1.0e-5) -> None: ...
	def Add(self, E: TopTools_ListOfShape, R: float) -> int: ...
	def CurveOnFace1(self, Index: int) -> Geom_Curve: ...
	def CurveOnFace2(self, Index: int) -> Geom_Curve: ...
	def Done(self) -> bool: ...
	def EndSectionStatus(self) -> FilletSurf_StatusType: ...
	def FirstParameter(self) -> float: ...
	def LastParameter(self) -> float: ...
	def NbSection(self, IndexSurf: int) -> int: ...
	def NbSurface(self) -> int: ...
	def PCurve1OnFillet(self, Index: int) -> Geom2d_Curve: ...
	def PCurve2OnFillet(self, Index: int) -> Geom2d_Curve: ...
	def PCurveOnFace1(self, Index: int) -> Geom2d_Curve: ...
	def PCurveOnFace2(self, Index: int) -> Geom2d_Curve: ...
	def Perform(self) -> None: ...
	def Section(self, IndexSurf: int, IndexSec: int, Circ: Geom_TrimmedCurve) -> None: ...
	def Simulate(self) -> None: ...
	def StartSectionStatus(self) -> FilletSurf_StatusType: ...
	def SupportFace1(self, Index: int) -> TopoDS_Face: ...
	def SupportFace2(self, Index: int) -> TopoDS_Face: ...
	def SurfaceFillet(self, Index: int) -> Geom_Surface: ...
	def TolApp3d(self, Index: int) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GccAna module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_gccana.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GccAna
else:
    import _GccAna

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GccAna.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GccAna.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GccAna.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GccAna.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GccAna.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GccAna.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GccAna.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GccAna.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GccAna.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GccAna.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GccAna.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GccAna.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GccAna.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GccAna:
_GccAna.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GccAna.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.GccEnt
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GccInt

from enum import IntEnum
from OCC.Core.Exception import *



class GccAna_Circ2d2TanOn(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to two 2d circles and having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a 2d line having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d lines having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a point having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d line and a point having the center on a 2d line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two points having the center on a 2d line.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        OnLine: gp_Lin2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d circles and having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and a line having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and a point having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d lines having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a line and a point having the center on a 2d circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two points having the center on a 2d circle.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        OnCirc: gp_Circ2d
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2d2TanOn_swiginit(self, _GccAna.new_GccAna_Circ2d2TanOn(*args))

    def CenterOn3(self, *args) -> "void":
        r"""
        Returns the informations about the center (on the curv) of the result number index and the third argument. pararg is the intrinsic parameter of the point pntarg on the third argument. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        PntArg: gp_Pnt2d

        Returns
        -------
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanOn_CenterOn3(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the construction algorithm does not fail (even if it finds no solution). note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanOn_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        True if the solution and the first argument are the same (2 circles). if r1 is the radius of the first argument and rsol the radius of the solution and dist the distance between the two centers, we concider the two circles are identical if r1+dist-rsol is less than tolerance. false in the other cases. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanOn_IsTheSame1(self, *args)

    def IsTheSame2(self, *args) -> "Standard_Boolean":
        r"""
        True if the solution and the second argument are the same (2 circles). if r2 is the radius of the second argument and rsol the radius of the solution and dist the distance between the two centers, we concider the two circles are identical if r2+dist-rsol is less than tolerance. false in the other cases. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanOn_IsTheSame2(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of circles, representing solutions computed by this algorithm. exceptions stdfail_notdone if the construction fails.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2d2TanOn_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns the informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution pararg is the intrinsic parameter of the point pntsol on the first argument. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanOn_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns the informations about the tangency point between the result number index and the second argument. parsol is the intrinsic parameter of the point pntsol on the solution. pararg is the intrinsic parameter of the point pntsol on the second argument. raises outofrange if index is greater than the number of solutions and notdone if isdone returns false.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanOn_Tangency2(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2d2TanOn_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifiers qualif1 and qualif2 of the tangency arguments for the solution of index index computed by this algorithm. the returned qualifiers are: - those specified at the start of construction when the solutions are defined as enclosed, enclosing or outside with respect to the arguments, or - those computed during construction (i.e. enclosed, enclosing or outside) when the solutions are defined as unqualified with respect to the arguments, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2d2TanOn_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2d2TanOn

# Register GccAna_Circ2d2TanOn in _GccAna:
_GccAna.GccAna_Circ2d2TanOn_swigregister(GccAna_Circ2d2TanOn)

class GccAna_Circ2d2TanRad(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to two 2d circle with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a 2d line with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d circle and a point with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a 2d line and a point with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to two 2d lines with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles passing through two points with a radius of radius. it raises negativevalue if radius is lower than zero.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2d2TanRad_swiginit(self, _GccAna.new_GccAna_Circ2d2TanRad(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanRad_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanRad_IsTheSame1(self, *args)

    def IsTheSame2(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the second argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d2TanRad_IsTheSame2(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of circles, representing solutions computed by this algorithm. exceptions stdfail_notdone if the construction fails. of solutions.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2d2TanRad_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns information about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution. pararg is the intrinsic parameter of the point pntsol on the first argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanRad_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns information about the tangency point between the result number index and the second argument. parsol is the intrinsic parameter of the point pntsol on the solution. pararg is the intrinsic parameter of the point pntarg on the second argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d2TanRad_Tangency2(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises outofrange exception if index is greater than the number of solutions. it raises notdone if the construction algorithm did not succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2d2TanRad_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the information about the qualifiers of the tangency arguments concerning the solution number index. it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computedin case of unqualified).

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2d2TanRad_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2d2TanRad

# Register GccAna_Circ2d2TanRad in _GccAna:
_GccAna.GccAna_Circ2d2TanRad_swigregister(GccAna_Circ2d2TanRad)

class GccAna_Circ2d3Tan(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to 3 circles. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Qualified3: GccEnt_QualifiedCirc
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 2 circles and 1 line. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Qualified3: GccEnt_QualifiedLin
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 1 circle and 2 lines. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        Qualified3: GccEnt_QualifiedLin
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 3 lines. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        Qualified3: GccEnt_QualifiedLin
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 2 circles and 1 point. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and a line and 1 point. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedLin
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to 2 lines and 1 point. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Qualified2: GccEnt_QualifiedLin
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a circle and passing thrue 2 points. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Point2: gp_Pnt2d
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a line and passing thrue 2 points. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        Point2: gp_Pnt2d
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles passing thrue 3 points. constructionerror is raised if there is a problem during the computation.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d
        Point3: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2d3Tan_swiginit(self, _GccAna.new_GccAna_Circ2d3Tan(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the construction algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsTheSame1(self, *args)

    def IsTheSame2(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the second argument. raises outofrange index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsTheSame2(self, *args)

    def IsTheSame3(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the third argument. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2d3Tan_IsTheSame3(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2d3Tan_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntarg on the argument curv. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d3Tan_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d3Tan_Tangency2(self, *args)

    def Tangency3(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2d3Tan_Tangency3(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises outofrange if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2d3Tan_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the informations about the qualifiers of the tangency arguments concerning the solution number index. it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computedin case of unqualified).

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position
        Qualif3: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2d3Tan_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2d3Tan

# Register GccAna_Circ2d3Tan in _GccAna:
_GccAna.GccAna_Circ2d3Tan_swigregister(GccAna_Circ2d3Tan)

class GccAna_Circ2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting curves between the two circles circ1 and circ2.

        Parameters
        ----------
        Circ1: gp_Circ2d
        Circ2: gp_Circ2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2dBisec_swiginit(self, _GccAna.new_GccAna_Circ2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the construction algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the solution number index raises outofrange exception if index is greater than the number of solutions. it raises notdone if the construction algorithm didn't succeed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_Circ2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2dBisec

# Register GccAna_Circ2dBisec in _GccAna:
_GccAna.GccAna_Circ2dBisec_swigregister(GccAna_Circ2dBisec)

class GccAna_Circ2dTanCen(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d circles tangent to a circle and centered on a point.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Pcenter: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles tangent to a line and centered on a point.

        Parameters
        ----------
        Linetan: gp_Lin2d
        Pcenter: gp_Pnt2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d circles passing thrue a point and centered on a point. tolerance is a tolerance criterion used by the algorithm to find a solution when, mathematically, the problem posed does not have a solution, but where there is numeric uncertainty attached to the arguments. in these algorithms tolerance is only used in very specific cases where the center of the solution is very close to the circle to which it is tangential, and where the solution is therefore a very small circle. exceptions gccent_badqualifier if a qualifier is inconsistent with the argument it qualifies (for example, enclosing for a line).

        Parameters
        ----------
        Point1: gp_Pnt2d
        Pcenter: gp_Pnt2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2dTanCen_swiginit(self, _GccAna.new_GccAna_Circ2dTanCen(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true if the construction algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanCen_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument. it raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions or less than zero.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanCen_IsTheSame1(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of circles, representing solutions computed by this algorithm and raises notdone exception if the algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2dTanCen_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntarg on the argument curv. it raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions or less than zero.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2dTanCen_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the circle, representing the solution number index and raises outofrange exception if index is greater than the number of solutions. be carefull: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions or less than zer.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2dTanCen_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosed, enclosing or it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computedin case of unqualified).

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2dTanCen_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2dTanCen

# Register GccAna_Circ2dTanCen in _GccAna:
_GccAna.GccAna_Circ2dTanCen_swigregister(GccAna_Circ2dTanCen)

class GccAna_Circ2dTanOnRad(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This methods implements the algorithms used to create 2d circles tangent to a circle and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. for example tolerance is used in the case of enclosedcirc when radius-r1+dist is greater tolerance (dist is the distance between the line and the location of the circ, r1 is the radius of the circ) because there is no solution. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        OnLine: gp_Lin2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles tangent to a 2d line and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        OnLine: gp_Lin2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles passing through a 2d point and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases.

        Parameters
        ----------
        Point1: gp_Pnt2d
        OnLine: gp_Lin2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles tangent to a circle and centered on a 2d circle with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        OnCirc: gp_Circ2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles tangent to a 2d line and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedLin
        OnCirc: gp_Circ2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d circles passing through a 2d point and centered on a 2d line with a given radius. tolerance is used to find solution in every limit cases. raises negativevalue in case of negativeradius.

        Parameters
        ----------
        Point1: gp_Pnt2d
        OnCirc: gp_Circ2d
        Radius: float
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Circ2dTanOnRad_swiginit(self, _GccAna.new_GccAna_Circ2dTanOnRad(*args))

    def CenterOn3(self, *args) -> "void":
        r"""
        Returns informations about the center (on the curv) of the result. pararg is the intrinsic parameter of the point on the argument curv. pntsol is the center point of the solution curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParArg: float

        """
        return _GccAna.GccAna_Circ2dTanOnRad_CenterOn3(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the construction algorithm does not fail (even if it finds no solution). note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanOnRad_IsDone(self, *args)

    def IsTheSame1(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the solution number index is equal to the first argument and false in the other cases. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Circ2dTanOnRad_IsTheSame1(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of circles, representing solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Circ2dTanOnRad_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. pntsol is the tangency point on the solution curv. pntarg is the tangency point on the argument curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Circ2dTanOnRad_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Circ2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Circ2d

        """
        return _GccAna.GccAna_Circ2dTanOnRad_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosed, enclosing or outside with respect to the argument, or - that computed during construction (i.e. enclosed, enclosing or outside) when the solutions are defined as unqualified with respect to the argument, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Circ2dTanOnRad_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Circ2dTanOnRad

# Register GccAna_Circ2dTanOnRad in _GccAna:
_GccAna.GccAna_Circ2dTanOnRad_swigregister(GccAna_Circ2dTanOnRad)

class GccAna_CircLin2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting curves between the circle circle and the line line.

        Parameters
        ----------
        Circle: gp_Circ2d
        Line: gp_Lin2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_CircLin2dBisec_swiginit(self, _GccAna.new_GccAna_CircLin2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true (this construction algorithm never fails).

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_CircLin2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of curves, representing solutions computed by this algorithm.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_CircLin2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_CircLin2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_CircLin2dBisec

# Register GccAna_CircLin2dBisec in _GccAna:
_GccAna.GccAna_CircLin2dBisec_swigregister(GccAna_CircLin2dBisec)

class GccAna_CircPnt2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting curves between the circle circle1 and the point point2.

        Parameters
        ----------
        Circle1: gp_Circ2d
        Point2: gp_Pnt2d

        Returns
        -------
        None
        Constructs bisecting curves between the circle circle1 and the point point2. tolerance is used.

        Parameters
        ----------
        Circle1: gp_Circ2d
        Point2: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_CircPnt2dBisec_swiginit(self, _GccAna.new_GccAna_CircPnt2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true (this construction algorithm never fails).

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_CircPnt2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of curves, representing solutions computed by this algorithm.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_CircPnt2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_CircPnt2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_CircPnt2dBisec

# Register GccAna_CircPnt2dBisec in _GccAna:
_GccAna.GccAna_CircPnt2dBisec_swigregister(GccAna_CircPnt2dBisec)

class GccAna_Lin2d2Tan(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This methods implements the algorithms used to create 2d lines passing thrue 2 points. tolerance is used because we can't create a line when the distance between the two points is too small.

        Parameters
        ----------
        ThePoint1: gp_Pnt2d
        ThePoint2: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d lines tangent to one circle and passing thrue a point. exception badqualifier is raised in the case of enclosedcirc tolerance is used because there is no solution when the point is inside the solution according to the tolerance.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        ThePoint: gp_Pnt2d
        Tolerance: float

        Returns
        -------
        None
        This methods implements the algorithms used to create 2d lines tangent to 2 circles. exception badqualifier is raised in the case of enclosedcirc.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Qualified2: GccEnt_QualifiedCirc
        Tolerance: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2d2Tan_swiginit(self, _GccAna.new_GccAna_Lin2d2Tan(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        This method returns true when there is a solution and false in the other cases.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2d2Tan_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        This method returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2d2Tan_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point pntsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange is raised if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2d2Tan_Tangency1(self, *args)

    def Tangency2(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the second argument. parsol is the intrinsic parameter of the point parsol on the solution curv. pararg is the intrinsic parameter of the point pntsol on the argument curv. raises outofrange is raised if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2d2Tan_Tangency2(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be carefull: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises outofrange is raised if index is greater than the number of solutions. it raises notdone if the algorithm failed.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2d2Tan_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifiers qualif1 and qualif2 of the tangency arguments for the solution of index index computed by this algorithm. the returned qualifiers are: - those specified at the start of construction when the solutions are defined as enclosing or outside with respect to the arguments, or - those computed during construction (i.e. enclosing or outside) when the solutions are defined as unqualified with respect to the arguments, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position
        Qualif2: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2d2Tan_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2d2Tan

# Register GccAna_Lin2d2Tan in _GccAna:
_GccAna.GccAna_Lin2d2Tan_swigregister(GccAna_Lin2d2Tan)

class GccAna_Lin2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs bisecting lines between the two lines lin1 and lin2.

        Parameters
        ----------
        Lin1: gp_Lin2d
        Lin2: gp_Lin2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dBisec_swiginit(self, _GccAna.new_GccAna_Lin2dBisec(*args))

    def Intersection1(self, *args) -> "void":
        r"""
        Returns informations about the intersection point between the result number index and the first argument. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dBisec_Intersection1(self, *args)

    def Intersection2(self, *args) -> "void":
        r"""
        Returns informations about the intersection point between the result number index and the second argument. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dBisec_Intersection2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when the algorithm succeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dBisec_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of solutions and raise notdone if the constructor wasn't called before.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dBisec_NbSolutions(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index . the first solution is the inside one and the second is the outside one. for the first solution the direction is d1+d2 (d1 is the direction of the first argument and d2 the direction of the second argument). for the second solution the direction is d1-d2. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dBisec

# Register GccAna_Lin2dBisec in _GccAna:
_GccAna.GccAna_Lin2dBisec_swigregister(GccAna_Lin2dBisec)

class GccAna_Lin2dTanObl(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This class implements the algorithms used to create 2d line passing through a point and making an angle with a line.

        Parameters
        ----------
        ThePoint: gp_Pnt2d
        TheLine: gp_Lin2d
        TheAngle: float

        Returns
        -------
        None
        This class implements the algorithms used to create 2d line tangent to a circle and making an angle with a line. exceptions gccent_badqualifier if a qualifier is inconsistent with the argument it qualifies (for example, enclosed for a circle).

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        TheLine: gp_Lin2d
        TheAngle: float

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dTanObl_swiginit(self, _GccAna.new_GccAna_Lin2dTanObl(*args))

    def Intersection2(self, *args) -> "void":
        r"""
        Returns informations about the intersection between the result number index and the third argument. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanObl_Intersection2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded. note: isdone protects against a failure arising from a more internal intersection algorithm, which has reached its numeric limits.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dTanObl_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of of lines, representing solutions computed by this algorithm. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dTanObl_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point parsol on the solution curv. pararg is the intrinsic parameter of the point pararg on the argument curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanObl_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index. be careful: the index is only a way to get all the solutions, but is not associated to theses outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dTanObl_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosing or outside with respect to the argument, or - that computed during construction (i.e. enclosing or outside) when the solutions are defined as unqualified with respect to the argument, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2dTanObl_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dTanObl

# Register GccAna_Lin2dTanObl in _GccAna:
_GccAna.GccAna_Lin2dTanObl_swigregister(GccAna_Lin2dTanObl)

class GccAna_Lin2dTanPar(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create a 2d line passing through a point and parallel to another line.

        Parameters
        ----------
        ThePoint: gp_Pnt2d
        Lin1: gp_Lin2d

        Returns
        -------
        None
        This method implements the algorithms used to create a 2d line tangent to a circle and parallel to another line. it raises badqualifier in case of enclosedcirc. exceptions gccent_badqualifier if a qualifier is inconsistent with the argument it qualifies (for example, enclosed for a circle).

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        Lin1: gp_Lin2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dTanPar_swiginit(self, _GccAna.new_GccAna_Lin2dTanPar(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dTanPar_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dTanPar_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. pararg is equal 0 when the solution is passing thrue a point. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        Pnt: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanPar_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dTanPar_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the informations about the qualifiers of the tangency arguments concerning the solution number index. it returns the real qualifiers (the qualifiers given to the constructor method in case of enclosed, enclosing and outside and the qualifiers computed in case of unqualified). raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2dTanPar_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dTanPar

# Register GccAna_Lin2dTanPar in _GccAna:
_GccAna.GccAna_Lin2dTanPar_swigregister(GccAna_Lin2dTanPar)

class GccAna_Lin2dTanPer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This method implements the algorithms used to create 2d lines passing through a point and perpendicular to a line.

        Parameters
        ----------
        ThePnt: gp_Pnt2d
        TheLin: gp_Lin2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d lines passing through a point and perpendicular to a circle.

        Parameters
        ----------
        ThePnt: gp_Pnt2d
        TheCircle: gp_Circ2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d lines tangent to a circle and perpendicular to a line.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        TheLin: gp_Lin2d

        Returns
        -------
        None
        This method implements the algorithms used to create 2d lines tangent to a circle and perpendicular to a circle.

        Parameters
        ----------
        Qualified1: GccEnt_QualifiedCirc
        TheCircle: gp_Circ2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Lin2dTanPer_swiginit(self, _GccAna.new_GccAna_Lin2dTanPer(*args))

    def Intersection2(self, *args) -> "void":
        r"""
        Returns informations about the intersection between the solution number index and the second argument. it returns the first intersection in a case of lin2dtanper which is perpendicular to a circle . parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        PntSol: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanPer_Intersection2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Lin2dTanPer_IsDone(self, *args)

    def NbSolutions(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of solutions. raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        int

        """
        return _GccAna.GccAna_Lin2dTanPer_NbSolutions(self, *args)

    def Tangency1(self, *args) -> "void":
        r"""
        Returns informations about the tangency point between the result number index and the first argument. parsol is the intrinsic parameter of the point on the solution curv. pararg is the intrinsic parameter of the point on the argument curv. if the first argument is a point pararg is equal zero. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int
        Pnt: gp_Pnt2d

        Returns
        -------
        ParSol: float
        ParArg: float

        """
        return _GccAna.GccAna_Lin2dTanPer_Tangency1(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns the solution number index and raises outofrange exception if index is greater than the number of solutions. be careful: the index is only a way to get all the solutions, but is not associated to those outside the context of the algorithm-object. raises notdone if the construction algorithm didn't succeed. it raises outofrange if index is greater than the number of solutions.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Lin2dTanPer_ThisSolution(self, *args)

    def WhichQualifier(self, *args) -> "void":
        r"""
        Returns the qualifier qualif1 of the tangency argument for the solution of index index computed by this algorithm. the returned qualifier is: - that specified at the start of construction when the solutions are defined as enclosing or outside with respect to the argument, or - that computed during construction (i.e. enclosing or outside) when the solutions are defined as unqualified with respect to the argument, or - gccent_noqualifier if the tangency argument is a point. exceptions standard_outofrange if index is less than zero or greater than the number of solutions computed by this algorithm. stdfail_notdone if the construction fails.

        Parameters
        ----------
        Index: int
        Qualif1: GccEnt_Position

        Returns
        -------
        None

        """
        return _GccAna.GccAna_Lin2dTanPer_WhichQualifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Lin2dTanPer

# Register GccAna_Lin2dTanPer in _GccAna:
_GccAna.GccAna_Lin2dTanPer_swigregister(GccAna_Lin2dTanPer)

class GccAna_LinPnt2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a bisecting curve between the line line1 and the point point2.

        Parameters
        ----------
        Line1: gp_Lin2d
        Point2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_LinPnt2dBisec_swiginit(self, _GccAna.new_GccAna_LinPnt2dBisec(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the algorithm succeeded.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_LinPnt2dBisec_IsDone(self, *args)

    def ThisSolution(self, *args) -> "opencascade::handle< GccInt_Bisec >":
        r"""
        Returns the number of solutions. it raises notdone if the construction algorithm didn't succeed.

        Returns
        -------
        opencascade::handle<GccInt_Bisec>

        """
        return _GccAna.GccAna_LinPnt2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_LinPnt2dBisec

# Register GccAna_LinPnt2dBisec in _GccAna:
_GccAna.GccAna_LinPnt2dBisec_swigregister(GccAna_LinPnt2dBisec)

class GccAna_Pnt2dBisec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a bisecting line between the points point1 and point2.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GccAna.GccAna_Pnt2dBisec_swiginit(self, _GccAna.new_GccAna_Pnt2dBisec(*args))

    def HasSolution(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this algorithm has a solution, i.e. if the two points are not coincident.

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Pnt2dBisec_HasSolution(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true (this construction algorithm never fails).

        Returns
        -------
        bool

        """
        return _GccAna.GccAna_Pnt2dBisec_IsDone(self, *args)

    def ThisSolution(self, *args) -> "gp_Lin2d":
        r"""
        Returns a line, representing the solution computed by this algorithm.

        Returns
        -------
        gp_Lin2d

        """
        return _GccAna.GccAna_Pnt2dBisec_ThisSolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GccAna.delete_GccAna_Pnt2dBisec

# Register GccAna_Pnt2dBisec in _GccAna:
_GccAna.GccAna_Pnt2dBisec_swigregister(GccAna_Pnt2dBisec)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.gp import *
from OCC.Core.TColgp import *
from OCC.Core.Geom import *
from OCC.Core.TColStd import *
from OCC.Core.TColGeom2d import *
from OCC.Core.Message import *
from OCC.Core.Geom2d import *
from OCC.Core.GeomLProp import *
from OCC.Core.Adaptor2d import *
from OCC.Core.Law import *
from OCC.Core.AdvApp2Var import *
from OCC.Core.GeomAbs import *
from OCC.Core.Plate import *


class GeomPlate_Array1OfHCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class GeomPlate_Array1OfSequenceOfReal:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TColStd_SequenceOfReal: ...
    def __setitem__(self, index: int, value: TColStd_SequenceOfReal) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TColStd_SequenceOfReal]: ...
    def next(self) -> TColStd_SequenceOfReal: ...
    __next__ = next
    def Init(self, theValue: TColStd_SequenceOfReal) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TColStd_SequenceOfReal: ...
    def Last(self) -> TColStd_SequenceOfReal: ...
    def Value(self, theIndex: int) -> TColStd_SequenceOfReal: ...
    def SetValue(self, theIndex: int, theValue: TColStd_SequenceOfReal) -> None: ...

class GeomPlate_SequenceOfAij:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> GeomPlate_Aij: ...
    def Last(self) -> GeomPlate_Aij: ...
    def Length(self) -> int: ...
    def Append(self, theItem: GeomPlate_Aij) -> GeomPlate_Aij: ...
    def Prepend(self, theItem: GeomPlate_Aij) -> GeomPlate_Aij: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> GeomPlate_Aij: ...
    def SetValue(self, theIndex: int, theValue: GeomPlate_Aij) -> None: ...

class GeomPlate_SequenceOfCurveConstraint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class GeomPlate_SequenceOfPointConstraint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class GeomPlate_Aij:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, anInd1: int, anInd2: int, aVec: gp_Vec) -> None: ...

class GeomPlate_BuildAveragePlane:
	@overload
	def __init__(self, Pts: TColgp_HArray1OfPnt, NbBoundPoints: int, Tol: float, POption: int, NOption: int) -> None: ...
	@overload
	def __init__(self, Normals: TColgp_SequenceOfVec, Pts: TColgp_HArray1OfPnt) -> None: ...
	@staticmethod
	def HalfSpace(NewNormals: TColgp_SequenceOfVec, Normals: TColgp_SequenceOfVec, Bset: GeomPlate_SequenceOfAij, LinTol: float, AngTol: float) -> bool: ...
	def IsLine(self) -> bool: ...
	def IsPlane(self) -> bool: ...
	def Line(self) -> Geom_Line: ...
	def MinMaxBox(self) -> Tuple[float, float, float, float]: ...
	def Plane(self) -> Geom_Plane: ...

class GeomPlate_BuildPlateSurface:
	@overload
	def __init__(self, NPoints: TColStd_HArray1OfInteger, TabCurve: GeomPlate_HArray1OfHCurve, Tang: TColStd_HArray1OfInteger, Degree: int, NbIter: Optional[int] = 3, Tol2d: Optional[float] = 0.00001, Tol3d: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1, Anisotropie: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Surf: Geom_Surface, Degree: Optional[int] = 3, NbPtsOnCur: Optional[int] = 10, NbIter: Optional[int] = 3, Tol2d: Optional[float] = 0.00001, Tol3d: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1, Anisotropie: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Degree: Optional[int] = 3, NbPtsOnCur: Optional[int] = 10, NbIter: Optional[int] = 3, Tol2d: Optional[float] = 0.00001, Tol3d: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1, Anisotropie: Optional[bool] = False) -> None: ...
	@overload
	def Add(self, Cont: GeomPlate_CurveConstraint) -> None: ...
	@overload
	def Add(self, Cont: GeomPlate_PointConstraint) -> None: ...
	def CurveConstraint(self, order: int) -> GeomPlate_CurveConstraint: ...
	def Curves2d(self) -> TColGeom2d_HArray1OfCurve: ...
	def Disc2dContour(self, nbp: int, Seq2d: TColgp_SequenceOfXY) -> None: ...
	def Disc3dContour(self, nbp: int, iordre: int, Seq3d: TColgp_SequenceOfXYZ) -> None: ...
	@overload
	def G0Error(self) -> float: ...
	@overload
	def G0Error(self, Index: int) -> float: ...
	@overload
	def G1Error(self) -> float: ...
	@overload
	def G1Error(self, Index: int) -> float: ...
	@overload
	def G2Error(self) -> float: ...
	@overload
	def G2Error(self, Index: int) -> float: ...
	def Init(self) -> None: ...
	def IsDone(self) -> bool: ...
	def LoadInitSurface(self, Surf: Geom_Surface) -> None: ...
	def Order(self) -> TColStd_HArray1OfInteger: ...
	def Perform(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def PointConstraint(self, order: int) -> GeomPlate_PointConstraint: ...
	def Sense(self) -> TColStd_HArray1OfInteger: ...
	def SetNbBounds(self, NbBounds: int) -> None: ...
	def SurfInit(self) -> Geom_Surface: ...
	def Surface(self) -> GeomPlate_Surface: ...

class GeomPlate_CurveConstraint(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Boundary: Adaptor3d_HCurve, Order: int, NPt: Optional[int] = 10, TolDist: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1) -> None: ...
	def Curve2dOnSurf(self) -> Geom2d_Curve: ...
	def Curve3d(self) -> Adaptor3d_HCurve: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec, V4: gp_Vec, V5: gp_Vec) -> None: ...
	def FirstParameter(self) -> float: ...
	def G0Criterion(self, U: float) -> float: ...
	def G1Criterion(self, U: float) -> float: ...
	def G2Criterion(self, U: float) -> float: ...
	def LPropSurf(self, U: float) -> GeomLProp_SLProps: ...
	def LastParameter(self) -> float: ...
	def Length(self) -> float: ...
	def NbPoints(self) -> int: ...
	def Order(self) -> int: ...
	def ProjectedCurve(self) -> Adaptor2d_HCurve2d: ...
	def SetCurve2dOnSurf(self, Curve2d: Geom2d_Curve) -> None: ...
	def SetG0Criterion(self, G0Crit: Law_Function) -> None: ...
	def SetG1Criterion(self, G1Crit: Law_Function) -> None: ...
	def SetG2Criterion(self, G2Crit: Law_Function) -> None: ...
	def SetNbPoints(self, NewNb: int) -> None: ...
	def SetOrder(self, Order: int) -> None: ...
	def SetProjectedCurve(self, Curve2d: Adaptor2d_HCurve2d, TolU: float, TolV: float) -> None: ...

class GeomPlate_MakeApprox:
	@overload
	def __init__(self, SurfPlate: GeomPlate_Surface, PlateCrit: AdvApp2Var_Criterion, Tol3d: float, Nbmax: int, dgmax: int, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1, EnlargeCoeff: Optional[float] = 1.1) -> None: ...
	@overload
	def __init__(self, SurfPlate: GeomPlate_Surface, Tol3d: float, Nbmax: int, dgmax: int, dmax: float, CritOrder: Optional[int] = 0, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1, EnlargeCoeff: Optional[float] = 1.1) -> None: ...
	def ApproxError(self) -> float: ...
	def CriterionError(self) -> float: ...
	def Surface(self) -> Geom_BSplineSurface: ...

class GeomPlate_PlateG0Criterion(AdvApp2Var_Criterion):
	def __init__(self, Data: TColgp_SequenceOfXY, G0Data: TColgp_SequenceOfXYZ, Maximum: float, Type: Optional[AdvApp2Var_CriterionType] = AdvApp2Var_Absolute, Repart: Optional[AdvApp2Var_CriterionRepartition] = AdvApp2Var_Regular) -> None: ...
	def IsSatisfied(self, P: AdvApp2Var_Patch) -> bool: ...
	def Value(self, P: AdvApp2Var_Patch, C: AdvApp2Var_Context) -> None: ...

class GeomPlate_PlateG1Criterion(AdvApp2Var_Criterion):
	def __init__(self, Data: TColgp_SequenceOfXY, G1Data: TColgp_SequenceOfXYZ, Maximum: float, Type: Optional[AdvApp2Var_CriterionType] = AdvApp2Var_Absolute, Repart: Optional[AdvApp2Var_CriterionRepartition] = AdvApp2Var_Regular) -> None: ...
	def IsSatisfied(self, P: AdvApp2Var_Patch) -> bool: ...
	def Value(self, P: AdvApp2Var_Patch, C: AdvApp2Var_Context) -> None: ...

class GeomPlate_PointConstraint(Standard_Transient):
	@overload
	def __init__(self, Pt: gp_Pnt, Order: int, TolDist: Optional[float] = 0.0001) -> None: ...
	@overload
	def __init__(self, U: float, V: float, Surf: Geom_Surface, Order: int, TolDist: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1) -> None: ...
	def D0(self, P: gp_Pnt) -> None: ...
	def D1(self, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D2(self, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec, V4: gp_Vec, V5: gp_Vec) -> None: ...
	def G0Criterion(self) -> float: ...
	def G1Criterion(self) -> float: ...
	def G2Criterion(self) -> float: ...
	def HasPnt2dOnSurf(self) -> bool: ...
	def LPropSurf(self) -> GeomLProp_SLProps: ...
	def Order(self) -> int: ...
	def Pnt2dOnSurf(self) -> gp_Pnt2d: ...
	def SetG0Criterion(self, TolDist: float) -> None: ...
	def SetG1Criterion(self, TolAng: float) -> None: ...
	def SetG2Criterion(self, TolCurv: float) -> None: ...
	def SetOrder(self, Order: int) -> None: ...
	def SetPnt2dOnSurf(self, Pnt: gp_Pnt2d) -> None: ...

class GeomPlate_Surface(Geom_Surface):
	def __init__(self, Surfinit: Geom_Surface, Surfinter: Plate_Plate) -> None: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def CallSurfinit(self) -> Geom_Surface: ...
	def Constraints(self, Seq: TColgp_SequenceOfXY) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def RealBounds(self) -> Tuple[float, float, float, float]: ...
	def SetBounds(self, Umin: float, Umax: float, Vmin: float, Vmax: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UPeriod(self) -> float: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VPeriod(self) -> float: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

# harray1 classes

class GeomPlate_HArray1OfSequenceOfReal(GeomPlate_Array1OfSequenceOfReal, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> GeomPlate_Array1OfSequenceOfReal: ...


class GeomPlate_HArray1OfHCurve(GeomPlate_Array1OfHCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> GeomPlate_Array1OfHCurve: ...

# harray2 classes
# hsequence classes

class GeomPlate_HSequenceOfPointConstraint(GeomPlate_SequenceOfPointConstraint, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GeomPlate_SequenceOfPointConstraint) -> None: ...
    def Sequence(self) -> GeomPlate_SequenceOfPointConstraint: ...
    def Append(self, theSequence: GeomPlate_SequenceOfPointConstraint) -> None: ...


class GeomPlate_HSequenceOfCurveConstraint(GeomPlate_SequenceOfCurveConstraint, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: GeomPlate_SequenceOfCurveConstraint) -> None: ...
    def Sequence(self) -> GeomPlate_SequenceOfCurveConstraint: ...
    def Append(self, theSequence: GeomPlate_SequenceOfCurveConstraint) -> None: ...


GeomPlate_BuildAveragePlane_HalfSpace = GeomPlate_BuildAveragePlane.HalfSpace



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Message import *
from OCC.Core.Poly import *
from OCC.Core.TopoDS import *
from OCC.Core.TCollection import *
from OCC.Core.Graphic3d import *
from OCC.Core.gp import *


class RWObj_SubMeshReason(IntEnum):
	RWObj_SubMeshReason_NewObject: int = ...
	RWObj_SubMeshReason_NewGroup: int = ...
	RWObj_SubMeshReason_NewMaterial: int = ...
	RWObj_SubMeshReason_NewSmoothGroup: int = ...
RWObj_SubMeshReason_NewObject = RWObj_SubMeshReason.RWObj_SubMeshReason_NewObject
RWObj_SubMeshReason_NewGroup = RWObj_SubMeshReason.RWObj_SubMeshReason_NewGroup
RWObj_SubMeshReason_NewMaterial = RWObj_SubMeshReason.RWObj_SubMeshReason_NewMaterial
RWObj_SubMeshReason_NewSmoothGroup = RWObj_SubMeshReason.RWObj_SubMeshReason_NewSmoothGroup

class rwobj:
	@staticmethod
	def ReadFile(theFile: str, aProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Poly_Triangulation: ...

class RWObj_IShapeReceiver:
	def BindNamedShape(self, theShape: TopoDS_Shape, theName: TCollection_AsciiString, theMaterial: RWObj_Material, theIsRootShape: bool) -> None: ...

class RWObj_Material:
	def __init__(self) -> None: ...

class RWObj_Reader(Standard_Transient):
	def ExternalFiles(self) -> False: ...
	def FileComments(self) -> TCollection_AsciiString: ...
	def IsSinglePrecision(self) -> bool: ...
	def MemoryLimit(self) -> int: ...
	def NbProbeElems(self) -> int: ...
	def NbProbeNodes(self) -> int: ...
	def Probe(self, theFile: TCollection_AsciiString, theProgress: Message_ProgressRange) -> bool: ...
	def Read(self, theFile: TCollection_AsciiString, theProgress: Message_ProgressRange) -> bool: ...
	def SetMemoryLimit(self, theMemLimit: int) -> None: ...
	def SetSinglePrecision(self, theIsSinglePrecision: bool) -> None: ...
	def Transformation(self) -> False: ...

class RWObj_SubMesh:
	pass

class RWObj_CafReader(RWMesh_CafReader, RWObj_IShapeReceiver):
	def __init__(self) -> None: ...
	def IsSinglePrecision(self) -> bool: ...
	def SetSinglePrecision(self, theIsSinglePrecision: bool) -> None: ...

class RWObj_TriangulationReader(RWObj_Reader):
	def __init__(self) -> None: ...
	def GetTriangulation(self) -> Poly_Triangulation: ...
	def ResultShape(self) -> TopoDS_Shape: ...
	def SetCreateShapes(self, theToCreateShapes: bool) -> None: ...
	def SetShapeReceiver(self, theReceiver: RWObj_IShapeReceiver) -> None: ...

#classnotwrapped
class RWObj_MtlReader: ...

# harray1 classes
# harray2 classes
# hsequence classes

rwobj_ReadFile = rwobj.ReadFile



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.TColStd import *
from OCC.Core.Aspect import *
from OCC.Core.TopoDS import *
from OCC.Core.Vrml import *
from OCC.Core.TopTools import *
from OCC.Core.HLRAlgo import *
from OCC.Core.Poly import *
from OCC.Core.TColgp import *
from OCC.Core.BRepAdaptor import *


class VrmlConverter_TypeOfLight(IntEnum):
	VrmlConverter_NoLight: int = ...
	VrmlConverter_DirectionLight: int = ...
	VrmlConverter_PointLight: int = ...
	VrmlConverter_SpotLight: int = ...
VrmlConverter_NoLight = VrmlConverter_TypeOfLight.VrmlConverter_NoLight
VrmlConverter_DirectionLight = VrmlConverter_TypeOfLight.VrmlConverter_DirectionLight
VrmlConverter_PointLight = VrmlConverter_TypeOfLight.VrmlConverter_PointLight
VrmlConverter_SpotLight = VrmlConverter_TypeOfLight.VrmlConverter_SpotLight

class VrmlConverter_TypeOfCamera(IntEnum):
	VrmlConverter_NoCamera: int = ...
	VrmlConverter_PerspectiveCamera: int = ...
	VrmlConverter_OrthographicCamera: int = ...
VrmlConverter_NoCamera = VrmlConverter_TypeOfCamera.VrmlConverter_NoCamera
VrmlConverter_PerspectiveCamera = VrmlConverter_TypeOfCamera.VrmlConverter_PerspectiveCamera
VrmlConverter_OrthographicCamera = VrmlConverter_TypeOfCamera.VrmlConverter_OrthographicCamera

class VrmlConverter_Curve:
	pass

class VrmlConverter_DeflectionCurve:
	pass

class VrmlConverter_Drawer(Standard_Transient):
	def __init__(self) -> None: ...
	def DeviationCoefficient(self) -> float: ...
	def DisableDrawHiddenLine(self) -> None: ...
	def Discretisation(self) -> int: ...
	def DrawHiddenLine(self) -> bool: ...
	def EnableDrawHiddenLine(self) -> None: ...
	def FreeBoundaryAspect(self) -> VrmlConverter_LineAspect: ...
	def FreeBoundaryDraw(self) -> bool: ...
	def HiddenLineAspect(self) -> VrmlConverter_LineAspect: ...
	def IsoOnPlane(self) -> bool: ...
	def LineAspect(self) -> VrmlConverter_LineAspect: ...
	def MaximalChordialDeviation(self) -> float: ...
	def MaximalParameterValue(self) -> float: ...
	def PointAspect(self) -> VrmlConverter_PointAspect: ...
	def SeenLineAspect(self) -> VrmlConverter_LineAspect: ...
	def SetDeviationCoefficient(self, aCoefficient: float) -> None: ...
	def SetDiscretisation(self, d: int) -> None: ...
	def SetFreeBoundaryAspect(self, anAspect: VrmlConverter_LineAspect) -> None: ...
	def SetFreeBoundaryDraw(self, OnOff: bool) -> None: ...
	def SetHiddenLineAspect(self, anAspect: VrmlConverter_LineAspect) -> None: ...
	def SetIsoOnPlane(self, OnOff: bool) -> None: ...
	def SetLineAspect(self, anAspect: VrmlConverter_LineAspect) -> None: ...
	def SetMaximalChordialDeviation(self, aChordialDeviation: float) -> None: ...
	def SetMaximalParameterValue(self, Value: float) -> None: ...
	def SetPointAspect(self, anAspect: VrmlConverter_PointAspect) -> None: ...
	def SetSeenLineAspect(self, anAspect: VrmlConverter_LineAspect) -> None: ...
	def SetShadingAspect(self, anAspect: VrmlConverter_ShadingAspect) -> None: ...
	def SetTypeOfDeflection(self, aTypeOfDeflection: Aspect_TypeOfDeflection) -> None: ...
	def SetUIsoAspect(self, anAspect: VrmlConverter_IsoAspect) -> None: ...
	def SetUnFreeBoundaryAspect(self, anAspect: VrmlConverter_LineAspect) -> None: ...
	def SetUnFreeBoundaryDraw(self, OnOff: bool) -> None: ...
	def SetVIsoAspect(self, anAspect: VrmlConverter_IsoAspect) -> None: ...
	def SetWireAspect(self, anAspect: VrmlConverter_LineAspect) -> None: ...
	def SetWireDraw(self, OnOff: bool) -> None: ...
	def ShadingAspect(self) -> VrmlConverter_ShadingAspect: ...
	def TypeOfDeflection(self) -> Aspect_TypeOfDeflection: ...
	def UIsoAspect(self) -> VrmlConverter_IsoAspect: ...
	def UnFreeBoundaryAspect(self) -> VrmlConverter_LineAspect: ...
	def UnFreeBoundaryDraw(self) -> bool: ...
	def VIsoAspect(self) -> VrmlConverter_IsoAspect: ...
	def WireAspect(self) -> VrmlConverter_LineAspect: ...
	def WireDraw(self) -> bool: ...

class VrmlConverter_HLRShape:
	pass

class VrmlConverter_LineAspect(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aMaterial: Vrml_Material, OnOff: bool) -> None: ...
	def HasMaterial(self) -> bool: ...
	def Material(self) -> Vrml_Material: ...
	def SetHasMaterial(self, OnOff: bool) -> None: ...
	def SetMaterial(self, aMaterial: Vrml_Material) -> None: ...

class VrmlConverter_PointAspect(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aMaterial: Vrml_Material, OnOff: bool) -> None: ...
	def HasMaterial(self) -> bool: ...
	def Material(self) -> Vrml_Material: ...
	def SetHasMaterial(self, OnOff: bool) -> None: ...
	def SetMaterial(self, aMaterial: Vrml_Material) -> None: ...

class VrmlConverter_Projector(Standard_Transient):
	def __init__(self, Shapes: TopTools_Array1OfShape, Focus: float, DX: float, DY: float, DZ: float, XUp: float, YUp: float, ZUp: float, Camera: Optional[VrmlConverter_TypeOfCamera] = VrmlConverter_NoCamera, Light: Optional[VrmlConverter_TypeOfLight] = VrmlConverter_NoLight) -> None: ...
	def Camera(self) -> VrmlConverter_TypeOfCamera: ...
	def Light(self) -> VrmlConverter_TypeOfLight: ...
	def Projector(self) -> HLRAlgo_Projector: ...
	def SetCamera(self, aCamera: VrmlConverter_TypeOfCamera) -> None: ...
	def SetLight(self, aLight: VrmlConverter_TypeOfLight) -> None: ...

class VrmlConverter_ShadedShape:
	@staticmethod
	def ComputeNormal(aFace: TopoDS_Face, pc: Poly_Connect, Nor: TColgp_Array1OfDir) -> None: ...

class VrmlConverter_ShadingAspect(Standard_Transient):
	def __init__(self) -> None: ...
	def FrontMaterial(self) -> Vrml_Material: ...
	def HasMaterial(self) -> bool: ...
	def HasNormals(self) -> bool: ...
	def SetFrontMaterial(self, aMaterial: Vrml_Material) -> None: ...
	def SetHasMaterial(self, OnOff: bool) -> None: ...
	def SetHasNormals(self, OnOff: bool) -> None: ...
	def SetShapeHints(self, aShapeHints: Vrml_ShapeHints) -> None: ...
	def ShapeHints(self) -> Vrml_ShapeHints: ...

class VrmlConverter_WFDeflectionRestrictedFace:
	pass

class VrmlConverter_WFDeflectionShape:
	pass

class VrmlConverter_WFRestrictedFace:
	pass

class VrmlConverter_WFShape:
	pass

class VrmlConverter_IsoAspect(VrmlConverter_LineAspect):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aMaterial: Vrml_Material, OnOff: bool, aNumber: int) -> None: ...
	def Number(self) -> int: ...
	def SetNumber(self, aNumber: int) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

VrmlConverter_Curve_Add = VrmlConverter_Curve.Add
VrmlConverter_Curve_Add = VrmlConverter_Curve.Add
VrmlConverter_Curve_Add = VrmlConverter_Curve.Add
VrmlConverter_DeflectionCurve_Add = VrmlConverter_DeflectionCurve.Add
VrmlConverter_DeflectionCurve_Add = VrmlConverter_DeflectionCurve.Add
VrmlConverter_DeflectionCurve_Add = VrmlConverter_DeflectionCurve.Add
VrmlConverter_DeflectionCurve_Add = VrmlConverter_DeflectionCurve.Add
VrmlConverter_DeflectionCurve_Add = VrmlConverter_DeflectionCurve.Add
VrmlConverter_DeflectionCurve_Add = VrmlConverter_DeflectionCurve.Add
VrmlConverter_HLRShape_Add = VrmlConverter_HLRShape.Add
VrmlConverter_ShadedShape_Add = VrmlConverter_ShadedShape.Add
VrmlConverter_ShadedShape_ComputeNormal = VrmlConverter_ShadedShape.ComputeNormal
VrmlConverter_WFDeflectionRestrictedFace_Add = VrmlConverter_WFDeflectionRestrictedFace.Add
VrmlConverter_WFDeflectionRestrictedFace_Add = VrmlConverter_WFDeflectionRestrictedFace.Add
VrmlConverter_WFDeflectionRestrictedFace_AddUIso = VrmlConverter_WFDeflectionRestrictedFace.AddUIso
VrmlConverter_WFDeflectionRestrictedFace_AddVIso = VrmlConverter_WFDeflectionRestrictedFace.AddVIso
VrmlConverter_WFDeflectionShape_Add = VrmlConverter_WFDeflectionShape.Add
VrmlConverter_WFRestrictedFace_Add = VrmlConverter_WFRestrictedFace.Add
VrmlConverter_WFRestrictedFace_Add = VrmlConverter_WFRestrictedFace.Add
VrmlConverter_WFRestrictedFace_AddUIso = VrmlConverter_WFRestrictedFace.AddUIso
VrmlConverter_WFRestrictedFace_AddVIso = VrmlConverter_WFRestrictedFace.AddVIso
VrmlConverter_WFShape_Add = VrmlConverter_WFShape.Add
